import { PropType, defineComponent, onMounted, reactive, ref } from 'vue';
import styles from './index.module.less';
import { NButton, NForm, NFormItem, NSpace } from 'naive-ui';
import { resourceTypeArray } from '/src/utils/searchArray';
import { useCatchStore } from '/src/store/modules/catchData';
import { useThrottleFn } from '@vueuse/core';
import TheSearch from '/src/components/TheSearch';

export default defineComponent({
  name: 'resource-search-group',
  props: {
    type: {
      type: String as PropType<'shareResources' | 'myResources' | 'myCollect'>,
      default: 'shareResources'
    }
  },
  emits: ['search'],
  setup(props, { emit }) {
    const catchStore = useCatchStore();
    const forms = reactive({
      type: 'MUSIC', //
      keyword: '',
      bookVersionId: null
    });
    const resourceType = ref([] as any);

    const onSearch = () => {
      emit('search', forms);
    };

    const throttleFn = useThrottleFn(() => onSearch(), 500);

    onMounted(async () => {
      if (props.type === 'myResources' || props.type === 'myCollect') {
        resourceType.value.push({
          label: '全部',
          value: ''
        });
        forms.type = ''; // 默认全部
      }
      resourceTypeArray.forEach((item: any) => {
        if (props.type === 'myResources') {
          item.value !== 'MUSIC' && resourceType.value.push(item);
        } else {
          resourceType.value.push(item);
        }
      });

      // 获取教材分类列表
      await catchStore.getMusicSheetCategory();
    });
    return () => (
      <div class={styles.searchGroup}>
        <div class={styles.searchCatatory}>
          <NSpace size="small" class={styles.btnType}>
            {resourceType.value.map((item: any) => (
              <NButton
                type={forms.type === item.value ? 'primary' : 'default'}
                secondary={forms.type === item.value ? false : true}
                round
                size="small"
                focusable={false}
                onClick={() => {
                  forms.type = item.value;
                  onSearch();
                }}>
                {item.label}
              </NButton>
            ))}
          </NSpace>

          <TheSearch
            class={styles.inputSearch}
            round
            onSearch={(val: string) => {
              forms.keyword = val;
              throttleFn();
            }}
          />
        </div>
        <NForm labelAlign="left" labelPlacement="left">
          {forms.type === 'MUSIC' && (
            <NFormItem label="教材：">
              <NSpace class={styles.spaceSection}>
                {catchStore.getAllMusicCategories.map((music: any) => (
                  <NButton
                    secondary={forms.bookVersionId === music.id}
                    quaternary={forms.bookVersionId !== music.id}
                    strong
                    focusable={false}
                    type={
                      forms.bookVersionId === music.id ? 'primary' : 'default'
                    }
                    onClick={() => {
                      forms.bookVersionId = music.id;
                      throttleFn();
                    }}>
                    {music.name}
                  </NButton>
                ))}
              </NSpace>
            </NFormItem>
          )}
        </NForm>
      </div>
    );
  }
});
